# Test Story

The idea behind DataStory is that it's hard to tell stories with data sometimes, so we all need
tools that help us do that as easily as possible. DataStory uses markdown to convert scripts and
content into great looking output that tells a story.

``` ruby-datastory
require 'gnuplot'
```

``` ruby-datastory
puts "This is a test"
output = 5 + 5
puts output
```

Here's some code with no output. It shouldn't have an output section under it.

``` ruby-datastory
output += 2
```

And then another output.
``` ruby-datastory
puts output
```

Now let's output a graph:

``` ruby-datastory
Gnuplot.open do |gp|
  Gnuplot::Plot.new(gp) do |plot|
    plot.terminal "gif"
    plot.output "tmp/sin_wave.gif"
  
    # see sin_wave.rb
    plot.xrange "[-10:10]"
    plot.title  "Sin Wave Example"
    plot.ylabel "sin(x)"
    plot.xlabel "x"
    
    plot.data << Gnuplot::DataSet.new( "sin(x)" ) do |ds|
      ds.with = "lines"
      ds.linewidth = 4
    end
    
  end
end
```

![Graph of Stuff](tmp/sin_wave.gif)

The following code uses the `append` method to append html output to the document.

``` ruby-datastory-erb
<table>
  <caption>Some random numbers.</caption>
  <tr>
    <% 6.times do |i| %>
      <th><%= i %></th>
    <% end %>
  </tr>
  <tr>
    <% 6.times do %>
      <td><%= rand %></td>
    <% end %>
  </tr>
</table>
```